aboutsummaryrefslogtreecommitdiff
path: root/cmd/golangorg
diff options
context:
space:
mode:
authorAlan Donovan <adonovan@google.com>2025-07-29 11:20:59 -0400
committerAlan Donovan <adonovan@google.com>2025-07-29 09:47:41 -0700
commite5dd27fc71edea3015b34b5061a4f4fe6e86f0cc (patch)
tree846c6b32cf8dc0a08048741cb265b890ac369df6 /cmd/golangorg
parent74641f3495984766c171703d06af11f123e07a11 (diff)
downloadgo-x-website-e5dd27fc71edea3015b34b5061a4f4fe6e86f0cc.tar.xz
cmd/golangorg: serve latest commit on gopls' latest release branch
Rather than serving docs at the gopls release itself, this CL causes us to serve whatever is on the release branch. This allows us to cherrypick doc fixes into the branch without all the fuss of a gopls release. Change-Id: I5f99458407388747a093219cac16e178f28ba527 Reviewed-on: https://go-review.googlesource.com/c/website/+/691415 Reviewed-by: Robert Findley <rfindley@google.com> LUCI-TryBot-Result: Go LUCI <golang-scoped@luci-project-accounts.iam.gserviceaccount.com> Reviewed-by: Dmitri Shuralyov <dmitshur@golang.org> Auto-Submit: Alan Donovan <adonovan@google.com>
Diffstat (limited to 'cmd/golangorg')
-rw-r--r--cmd/golangorg/server.go5
1 files changed, 3 insertions, 2 deletions
diff --git a/cmd/golangorg/server.go b/cmd/golangorg/server.go
index 85af5afe..71218c05 100644
--- a/cmd/golangorg/server.go
+++ b/cmd/golangorg/server.go
@@ -200,8 +200,9 @@ func NewHandler(contentDir, goroot string) http.Handler {
go watchGit(&tipGoroot, "https://go.googlesource.com/go", "HEAD")
}
- // go.dev/gopls serves the latest gopls release of golang.org/x/tools/gopls/doc.
- contentFS = addGopls(contentFS, "gopls/latest")
+ // go.dev/gopls serves golang.org/x/tools/gopls/doc from the
+ // tip commit on the latest release branch.
+ contentFS = addGopls(contentFS, "gopls/latest-release-branch")
// beta.golang.org is an old name for tip.
mux.Handle("beta.golang.org/", redirectPrefix("https://tip.golang.org/"))